'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _stream = require('../core/stream');

var _stream2 = _interopRequireDefault(_stream);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @private
 * @class TumblrStream
 * @description TumblrStream class
 * @example
 *
 * const stream = tumblr.stream('blog/:blog-identifier/posts');
 *
 * stream.on('message', (message) => {
 *  console.log(message);
 * });
 *
 * // handle stream error
 * stream.on('error', (err) => {
 *  // An error occur
 *  console.log(err);
 * });
 */
var TumblrStream = function (_Stream) {
  _inherits(TumblrStream, _Stream);

  /**
   * @private
   * @memberof TumblrStream
   * @description Create a new instance of TumblrStream class
   */
  function TumblrStream(tumblr, endpoint) {
    var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

    _classCallCheck(this, TumblrStream);

    var _this = _possibleConstructorReturn(this, (TumblrStream.__proto__ || Object.getPrototypeOf(TumblrStream)).call(this, options));

    _this.tumblr = tumblr;
    _this.endpoint = endpoint;
    _this.interval = options.interval || 20000;
    if (options.runOnCreation !== false) {
      _this.start();
    }
    return _this;
  }

  /**
   * @memberof TumblrStream
   * @private
   * @description Make a request on tumblr API.<br />
   * Cache the result and emit only new messages.
   */


  _createClass(TumblrStream, [{
    key: 'makeRequest',
    value: function makeRequest() {
      var _this2 = this;

      this.tumblr.get(this.endpoint).then(function (data) {
        var posts = data.response.posts;
        if (posts.length > 0) {
          var _cache;

          // Only return messages not in cache
          var newPosts = posts.filter(function (post) {
            return _this2.cache.indexOf(post.id) === -1;
          });
          (_cache = _this2.cache).push.apply(_cache, _toConsumableArray(newPosts.map(function (post) {
            return post.id;
          })));
          // Only return messages created after the stream
          newPosts = newPosts.filter(function (post) {
            return _this2.startDate < new Date(post.date);
          });
          if (newPosts.length > 0) {
            newPosts.forEach(function (newPost) {
              _this2.emit('message', newPost);
            });
          }
        }
      }).catch(function (err) {
        _this2.emit('error', err.error || err);
      });
    }
  }]);

  return TumblrStream;
}(_stream2.default);

exports.default = TumblrStream;